@@ -509,8 +509,11 @@ verb_HelpAbout_cb (GtkAction *action, gpointer data)
 	GdkPixbuf *pixbuf;
 	
 	static const char *authors[] = {
-		"Jens Finke <jens@triq.net>",
+		"Tim Gerla <tim+gnomebugs@gerla.net> (maintainer)",
 		"",
+		"Philip Van Hoof <pvanhoof@gnome.org>",
+                "Paolo Borelli <pborelli@katamail.com>",
+		"Jens Finke <jens@triq.net>",
 		"Martin Baulig <martin@home-of-linux.org>",
 		"Arik Devens <arik@gnome.org>",
 		"Michael Meeks <mmeeks@gnu.org>",
@@ -2882,7 +2885,6 @@ display_image_data (EogWindow *window, EogImage *image)
 
 	eog_scroll_view_set_image (EOG_SCROLL_VIEW (priv->scroll_view), image);
 	eog_info_view_set_image (EOG_INFO_VIEW (priv->info_view), image);
-	update_status_bar (window);
 
 	if (priv->displayed_image != NULL)
 		g_object_unref (priv->displayed_image);
@@ -2895,7 +2897,9 @@ display_image_data (EogWindow *window, EogImage *image)
 		title = _("Eye of GNOME");		
 	}
 
-	gtk_window_set_title (GTK_WINDOW (window), title);		
+	gtk_window_set_title (GTK_WINDOW (window), title);
+
+	update_status_bar (window);
 }
 
 /* this runs in its own thread */
@@ -3371,7 +3375,7 @@ eog_window_construct_ui (EogWindow *window, GError **error)
 	/* left side holds the image view, right side the info view */
 	priv->hpane = gtk_hpaned_new (); /* eog_horizontal_splitter_new ();  */
 	gtk_paned_pack1 (GTK_PANED (priv->hpane), frame, TRUE, TRUE);
-	gtk_paned_pack2 (GTK_PANED (priv->hpane), priv->info_view, TRUE, TRUE);
+	gtk_paned_pack2 (GTK_PANED (priv->hpane), priv->info_view, FALSE, TRUE);
 
 	gtk_paned_pack1 (GTK_PANED (priv->vpane), priv->hpane, TRUE, TRUE);
 
